export default aabUtilsMethods;
export type ApkCreationOptions = {
    /**
     * Specifies the path to the deployment keystore used
     * to sign the APKs. This flag is optional. If you don't include it,
     * bundletool attempts to sign your APKs with a debug signing key.
     * If the .apk has been already signed and cached then it is not going to be resigned
     * unless a different keystore or key alias is used.
     */
    keystore?: string | undefined;
    /**
     * Specifies your keystore’s password.
     * It is mandatory to provide this value if `keystore` one is assigned
     * otherwise it is going to be ignored.
     */
    keystorePassword?: string | undefined;
    /**
     * Specifies the alias of the signing key you want to use.
     * It is mandatory to provide this value if `keystore` one is assigned
     * otherwise it is going to be ignored.
     */
    keyAlias?: string | undefined;
    /**
     * Specifies the password for the signing key.
     * It is mandatory to provide this value if `keystore` one is assigned
     * otherwise it is going to be ignored.
     */
    keyPassword?: string | undefined;
};
export type AabUtils = typeof aabUtilsMethods;
declare namespace aabUtilsMethods {
    /**
     * @typedef {Object} ApkCreationOptions
     * @property {string} [keystore] Specifies the path to the deployment keystore used
     * to sign the APKs. This flag is optional. If you don't include it,
     * bundletool attempts to sign your APKs with a debug signing key.
     * If the .apk has been already signed and cached then it is not going to be resigned
     * unless a different keystore or key alias is used.
     * @property {string} [keystorePassword] Specifies your keystore’s password.
     * It is mandatory to provide this value if `keystore` one is assigned
     * otherwise it is going to be ignored.
     * @property {string} [keyAlias] Specifies the alias of the signing key you want to use.
     * It is mandatory to provide this value if `keystore` one is assigned
     * otherwise it is going to be ignored.
     * @property {string} [keyPassword] Specifies the password for the signing key.
     * It is mandatory to provide this value if `keystore` one is assigned
     * otherwise it is going to be ignored.
     */
    /**
     * Builds a universal .apk from the given .aab package. See
     * https://developer.android.com/studio/command-line/bundletool#generate_apks
     * for more details.
     *
     * @this {import('../adb.js').ADB}
     * @param {string} aabPath Full path to the source .aab package
     * @param {ApkCreationOptions} [opts={}]
     * @returns The path to the resulting universal .apk. The .apk is stored in the internal cache
     * by default.
     * @throws {Error} If there was an error while creating the universal .apk
     */
    function extractUniversalApk(this: import("../adb.js").ADB, aabPath: string, opts?: ApkCreationOptions | undefined): Promise<string>;
}
//# sourceMappingURL=aab-utils.d.ts.map